@@ -114,7 +114,17 @@ class HttpsRedirect(
         :param record_names: The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpsRedirect.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                target_domain: builtins.str,
+                zone: aws_cdk.aws_route53.IHostedZone,
+                certificate: typing.Optional[aws_cdk.aws_certificatemanager.ICertificate] = None,
+                record_names: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = HttpsRedirectProps(
@@ -167,7 +177,15 @@ class HttpsRedirectProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpsRedirectProps.__init__)
+            def stub(
+                *,
+                target_domain: builtins.str,
+                zone: aws_cdk.aws_route53.IHostedZone,
+                certificate: typing.Optional[aws_cdk.aws_certificatemanager.ICertificate] = None,
+                record_names: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_domain", value=target_domain, expected_type=type_hints["target_domain"])
             check_type(argname="argument zone", value=zone, expected_type=type_hints["zone"])
             check_type(argname="argument certificate", value=certificate, expected_type=type_hints["certificate"])
